@@ -107,6 +107,7 @@ class Response(object):
             'version': self.version,
             'status_code': self.status_code,
             'status_reason': self.status_reason,
+            'body': self.body.to_dict(),
         }
 
 
@@ -146,6 +147,16 @@ class Body(object, metaclass=abc.ABCMeta):
             self.content_file.seek(0, os.SEEK_END)
             return self.content_file.tell()
 
+    def to_dict(self):
+        if not hasattr(self.content_file, 'name'):
+            # Make SpooledTemporaryFile rollover to real file
+            self.content_file.fileno()
+
+        return {
+            'filename': self.content_file.name,
+            'content_size': self.content_size,
+        }
+
 
 class Connection(object):
     class ConnectionEvents(object):
